summaryrefslogtreecommitdiff
path: root/scripts/config.pl
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/config.pl')
-rwxr-xr-xscripts/config.pl6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/config.pl b/scripts/config.pl
index 79b1c49..af58012 100755
--- a/scripts/config.pl
+++ b/scripts/config.pl
@@ -1,6 +1,6 @@
#!/usr/bin/perl
# The yChat Project (2004, 2005)
#
# This script modifues the src/glob.h file.
@@ -8,11 +8,11 @@ use strict;
use scripts::modules::file;
print <<END;
-Welcome to the yChat configurator!
+Welcome to the yhttpd configurator!
You may also edit the src/glob.h file manually instead of using
this configurator option. Please also notice that this are only
before-compile options. All setups which can be made after com-
-iling are placed in the yChat configuration file.
+iling are placed in the yhttpd configuration file.
END
my $sep = "================================================================\n";
@@ -1,6 +1,6 @@
#!/usr/bin/perl
-# The yChat Project (2004, 2005)
+# The yhttpd Project (2004, 2005)
#
# This script modifues the src/glob.h file.